Package: foreach
Type: Package
Title: Provides Foreach Looping Construct
Version: 1.5.2
Authors@R: c(person("Folashade", "Daniel", role="cre", email="fdaniel@microsoft.com"),
             person("Hong", "Ooi", role="ctb"),
             person("Rich", "Calaway", role="ctb"),
             person("Microsoft", role=c("aut", "cph")),
             person("Steve", "Weston", role="aut"))
Description: Support for the foreach looping construct.  Foreach is an
        idiom that allows for iterating over elements in a collection,
        without the use of an explicit loop counter.  This package in
        particular is intended to be used for its return value, rather
        than for its side effects.  In that sense, it is similar to the
        standard lapply function, but doesn't require the evaluation
        of a function.  Using foreach without side effects also
        facilitates executing the loop in parallel.
License: Apache License (== 2.0)
URL: https://github.com/RevolutionAnalytics/foreach
BugReports: https://github.com/RevolutionAnalytics/foreach/issues
Depends: R (>= 2.5.0)
Imports: codetools, utils, iterators
Suggests: randomForest, doMC, doParallel, testthat, knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.1.1
Collate: 'callCombine.R' 'foreach.R' 'do.R' 'foreach-ext.R'
        'foreach-pkg.R' 'getDoPar.R' 'getDoSeq.R' 'getsyms.R' 'iter.R'
        'nextElem.R' 'onLoad.R' 'setDoPar.R' 'setDoSeq.R' 'times.R'
        'utils.R'
NeedsCompilation: no
Packaged: 2022-01-11 04:21:12 UTC; fdaniel
Author: Folashade Daniel [cre],
  Hong Ooi [ctb],
  Rich Calaway [ctb],
  Microsoft [aut, cph],
  Steve Weston [aut]
Maintainer: Folashade Daniel <fdaniel@microsoft.com>
Repository: CRAN
Date/Publication: 2022-02-02 09:20:02 UTC
Built: R 4.4.2; ; 2026-01-07 07:28:39 UTC; unix
