Package: foreach
Type: Package
Title: Provides Foreach Looping Construct for R
Version: 1.4.4
Authors@R: c(person("Rich", "Calaway", role="cre", email="richcala@microsoft.com"),
             person("Microsoft", role=c("aut", "cph")),
			 person("Steve", "Weston", role="aut"))
Description: Support for the foreach looping construct.  Foreach is an
        idiom that allows for iterating over elements in a collection,
        without the use of an explicit loop counter.  This package in
        particular is intended to be used for its return value, rather
        than for its side effects.  In that sense, it is similar to the
        standard lapply function, but doesn't require the evaluation
        of a function.  Using foreach without side effects also
        facilitates executing the loop in parallel.
Depends: R (>= 2.5.0)
Imports: codetools, utils, iterators
Suggests: randomForest
Enhances: compiler, doMC, RUnit, doParallel
License: Apache License (== 2.0)
Author: Rich Calaway [cre],
  Microsoft [aut, cph],
  Steve Weston [aut]
Maintainer: Rich Calaway <richcala@microsoft.com>
Repository: CRAN
Repository/R-Forge/Project: foreach
Repository/R-Forge/Revision: 31
Repository/R-Forge/DateTimeStamp: 2017-12-08 23:08:19
Date/Publication: 2017-12-12 22:37:36 UTC
NeedsCompilation: no
Packaged: 2017-12-08 23:33:48 UTC; rforge
Built: R 3.4.1; ; 2018-03-10 10:28:18 UTC; windows
