# Generated by roxygen2: do not edit by hand

S3method(accumulate,ifilteredforeach)
S3method(accumulate,iforeach)
S3method(accumulate,ixforeach)
S3method(getErrorIndex,ifilteredforeach)
S3method(getErrorIndex,iforeach)
S3method(getErrorIndex,ixforeach)
S3method(getErrorValue,ifilteredforeach)
S3method(getErrorValue,iforeach)
S3method(getErrorValue,ixforeach)
S3method(getResult,ifilteredforeach)
S3method(getResult,iforeach)
S3method(getResult,ixforeach)
S3method(iter,filteredforeach)
S3method(iter,foreach)
S3method(iter,xforeach)
S3method(nextElem,ifilteredforeach)
S3method(nextElem,iforeach)
S3method(nextElem,ixforeach)
export("%:%")
export("%do%")
export("%dopar%")
export(accumulate)
export(foreach)
export(getDoParName)
export(getDoParRegistered)
export(getDoParVersion)
export(getDoParWorkers)
export(getDoSeqName)
export(getDoSeqRegistered)
export(getDoSeqVersion)
export(getDoSeqWorkers)
export(getErrorIndex)
export(getErrorValue)
export(getResult)
export(getexports)
export(makeAccum)
export(registerDoSEQ)
export(setDoPar)
export(setDoSeq)
export(times)
export(when)
import(iterators)
importFrom(codetools,findGlobals)
importFrom(utils,packageDescription)
