export(foreach, when, times, "%do%", "%dopar%", "%:%", registerDoSEQ,
       getDoSeqRegistered, getDoSeqWorkers, getDoSeqName, getDoSeqVersion,
       setDoSeq, getDoParRegistered, getDoParWorkers, getDoParName,
       getDoParVersion, setDoPar, getResult, getErrorValue, getErrorIndex,
       accumulate, makeAccum, getexports)
S3method("iter", "foreach")
S3method("iter", "filteredforeach")
S3method("iter", "xforeach")
S3method("nextElem", "iforeach")
S3method("nextElem", "ifilteredforeach")
S3method("nextElem", "ixforeach")
S3method("getResult", "iforeach")
S3method("getResult", "ifilteredforeach")
S3method("getResult", "ixforeach")
S3method("getErrorValue", "iforeach")
S3method("getErrorValue", "ifilteredforeach")
S3method("getErrorValue", "ixforeach")
S3method("getErrorIndex", "iforeach")
S3method("getErrorIndex", "ifilteredforeach")
S3method("getErrorIndex", "ixforeach")
S3method("accumulate", "iforeach")
S3method("accumulate", "ifilteredforeach")
S3method("accumulate", "ixforeach")
import(iterators)
importFrom(codetools, "findGlobals")
importFrom(utils, "packageDescription")
